@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Factory;
-$Footprintless::Factory::VERSION = '1.19';
+$Footprintless::Factory::VERSION = '1.20';
 # ABSTRACT: The default factory for footprintless modules
 # PODNAME: Footprintless::Factory
 
@@ -141,10 +141,12 @@ sub register_plugin {
 }
 
 sub resource_manager {
-    my ($self) = @_;
+    my ( $self, $coordinate, %options ) = @_;
 
     unless ( $self->{resource_manager} ) {
-        $self->{resource_manager} = Footprintless::Util::resource_manager( $self->agent() );
+        $self->{resource_manager} =
+            Footprintless::Util::dynamic_module_new( 'Footprintless::ResourceManager',
+            $self, $coordinate );
     }
 
     return $self->{resource_manager};
@@ -176,7 +178,7 @@ Footprintless::Factory - The default factory for footprintless modules
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
