@@ -2,23 +2,23 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::MavenProvider;
-$Footprintless::Resource::MavenProvider::VERSION = '1.19';
+$Footprintless::Resource::MavenProvider::VERSION = '1.20';
 # ABSTRACT: A resource provider for resources retrieved by maven coordinate
 # PODNAME: Footprintless::Resource::MavenProvider
 
 use parent qw(Footprintless::Resource::Provider);
 
+use Maven::Agent;
+
 sub _download {
     my ( $self, $resource, %options ) = @_;
     return $self->{maven_agent}->download( $resource->get_artifact(), %options );
 }
 
 sub _init {
-    my ( $self, $maven_agent ) = @_;
+    my ( $self, %options ) = @_;
 
-    $self->Footprintless::Resource::Provider::_init();
-
-    $self->{maven_agent} = $maven_agent;
+    $self->{maven_agent} = Maven::Agent->new( agent => $self->{factory}->agent() );
 
     return $self;
 }
@@ -60,15 +60,7 @@ Footprintless::Resource::MavenProvider - A resource provider for resources retri
 
 =head1 VERSION
 
-version 1.19
-
-=head1 CONSTRUCTORS
-
-=head2 new($maven_agent)
-
-Creates a new C<Footprintless::Resource::MavenProvider> that will use 
-C<$maven_agent> to retrieve the resources.  C<$maven_agent> should be an 
-instance of C<Maven::Agent>.
+version 1.20
 
 =head1 METHODS
 
