@@ -2,10 +2,12 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::Provider;
-$Footprintless::Resource::Provider::VERSION = '1.19';
+$Footprintless::Resource::Provider::VERSION = '1.20';
 # ABSTRACT: A contract for providing resources to the resource manager
 # PODNAME: Footprintless::Resource::Provider
 
+use parent qw(Footprintless::MixableBase);
+
 use Carp;
 use Footprintless::Util qw(
     temp_file
@@ -14,10 +16,6 @@ use Log::Any;
 
 my $logger = Log::Any->get_logger();
 
-sub new {
-    return bless( {}, shift )->_init(@_);
-}
-
 sub download {
     my ( $self, $resource, @options ) = @_;
 
@@ -35,11 +33,6 @@ sub _download {
     croak( __PACKAGE__ . " does not support [$resource]" );
 }
 
-sub _init {
-    my ($self) = @_;
-    return $self;
-}
-
 sub resource {
     my ( $self, $spec ) = @_;
     croak( __PACKAGE__ . " does not support [$spec]" );
@@ -62,7 +55,7 @@ Footprintless::Resource::Provider - A contract for providing resources to the re
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
@@ -72,12 +65,6 @@ be used directly.  Instead an instance of
 C<Footprintless::ResourceManager> should be initialized with an ordered
 list of providers.  See L<Footprintless::ResourceManager> for usage.
 
-=head1 CONSTRUCTORS
-
-=head2 new(@args)
-
-See implementation classes.
-
 =head1 METHODS
 
 =head2 download($resource, %options)
