@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::UrlProvider;
-$Footprintless::Resource::UrlProvider::VERSION = '1.19';
+$Footprintless::Resource::UrlProvider::VERSION = '1.20';
 # ABSTRACT: A resource provider for resources retrieved by URL
 # PODNAME: Footprintless::Resource::UrlProvider
 
@@ -47,11 +47,9 @@ sub _download {
 }
 
 sub _init {
-    my ( $self, $agent ) = @_;
+    my ($self) = @_;
 
-    $self->Footprintless::Resource::Provider::_init();
-
-    $self->{agent} = $agent;
+    $self->{agent} = $self->{factory}->agent();
 
     return $self;
 }
@@ -82,7 +80,7 @@ Footprintless::Resource::UrlProvider - A resource provider for resources retriev
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 CONSTRUCTORS
 
