@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.19';
+$Footprintless::Util::VERSION = '1.20';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -20,7 +20,6 @@ our @EXPORT_OK = qw(
     extract
     factory
     invalid_entity
-    resource_manager
     rebase
     slurp
     spurt
@@ -195,23 +194,6 @@ sub rebase {
     return $rebased;
 }
 
-sub resource_manager {
-    my ($agent) = @_;
-    $agent ||= agent();
-
-    my @providers = ();
-    if ( require Maven::Agent ) {
-        require Footprintless::Resource::MavenProvider;
-        push( @providers,
-            Footprintless::Resource::MavenProvider->new( Maven::Agent->new( agent => $agent ) ) );
-    }
-
-    require Footprintless::ResourceManager;
-    require Footprintless::Resource::UrlProvider;
-    return Footprintless::ResourceManager->new( @providers,
-        Footprintless::Resource::UrlProvider->new($agent) );
-}
-
 sub slurp {
     my ($file) = @_;
 
@@ -265,7 +247,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
@@ -276,7 +258,6 @@ version 1.19
         dumper
         exit_due_to
         extract
-        resource_manager
         slurp
         spurt
         temp_dir
@@ -380,14 +361,6 @@ Replaces a portion of the start of C<$path>.  C<\%rebase> must have 2 keys,
 C<from> and C<to>.  The C<from> value will be removed from C<$path> and
 replaced with the C<to> value.
 
-=head2 resource_manager($agent)
-
-Returns a new instance of C<Footprintless::ResourceManager> configured with 
-a L<maven provider|Footprintless::Resource::MavenProvider> if C<Maven::Agent> 
-is available, and a L<url provider|Footprintless::Resource::UrlProvider> 
-in that order.  If C<$agent> is provided, it will be passed on to the 
-providers.
-
 =head2 slurp([$file])
 
 Reads the entire contents of C<$file> in one gulp.  If C<$file> is 
